==> istio-model-v1beta1-5.12.3-sources.jar: io/fabric8/istio/api/networking/v1beta1/OutlierDetectionBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OutlierDetectionBuilder extends io.fabric8.istio.api.networking.v1beta1.OutlierDetectionFluentImpl<io.fabric8.istio.api.networking.v1beta1.OutlierDetectionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.istio.api.networking.v1beta1.OutlierDetection,io.fabric8.istio.api.networking.v1beta1.OutlierDetectionBuilder>{
  public OutlierDetectionBuilder() {
    this(false);
  }
  public OutlierDetectionBuilder(java.lang.Boolean validationEnabled) {
    this(new OutlierDetection(), validationEnabled);
  }
  public OutlierDetectionBuilder(io.fabric8.istio.api.networking.v1beta1.OutlierDetectionFluent<?> fluent) {
    this(fluent, false);
  }
  public OutlierDetectionBuilder(io.fabric8.istio.api.networking.v1beta1.OutlierDetectionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new OutlierDetection(), validationEnabled);
  }
  public OutlierDetectionBuilder(io.fabric8.istio.api.networking.v1beta1.OutlierDetectionFluent<?> fluent,io.fabric8.istio.api.networking.v1beta1.OutlierDetection instance) {
    this(fluent, instance, false);
  }
  public OutlierDetectionBuilder(io.fabric8.istio.api.networking.v1beta1.OutlierDetectionFluent<?> fluent,io.fabric8.istio.api.networking.v1beta1.OutlierDetection instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withBaseEjectionTime(instance.getBaseEjectionTime()); 
    fluent.withConsecutive5xxErrors(instance.getConsecutive5xxErrors()); 
    fluent.withConsecutiveErrors(instance.getConsecutiveErrors()); 
    fluent.withConsecutiveGatewayErrors(instance.getConsecutiveGatewayErrors()); 
    fluent.withConsecutiveLocalOriginFailures(instance.getConsecutiveLocalOriginFailures()); 
    fluent.withInterval(instance.getInterval()); 
    fluent.withMaxEjectionPercent(instance.getMaxEjectionPercent()); 
    fluent.withMinHealthPercent(instance.getMinHealthPercent()); 
    fluent.withSplitExternalLocalOriginErrors(instance.getSplitExternalLocalOriginErrors()); 
    this.validationEnabled = validationEnabled; 
  }
  public OutlierDetectionBuilder(io.fabric8.istio.api.networking.v1beta1.OutlierDetection instance) {
    this(instance,false);
  }
  public OutlierDetectionBuilder(io.fabric8.istio.api.networking.v1beta1.OutlierDetection instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withBaseEjectionTime(instance.getBaseEjectionTime()); 
    this.withConsecutive5xxErrors(instance.getConsecutive5xxErrors()); 
    this.withConsecutiveErrors(instance.getConsecutiveErrors()); 
    this.withConsecutiveGatewayErrors(instance.getConsecutiveGatewayErrors()); 
    this.withConsecutiveLocalOriginFailures(instance.getConsecutiveLocalOriginFailures()); 
    this.withInterval(instance.getInterval()); 
    this.withMaxEjectionPercent(instance.getMaxEjectionPercent()); 
    this.withMinHealthPercent(instance.getMinHealthPercent()); 
    this.withSplitExternalLocalOriginErrors(instance.getSplitExternalLocalOriginErrors()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.istio.api.networking.v1beta1.OutlierDetectionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.istio.api.networking.v1beta1.OutlierDetection build() {
    OutlierDetection buildable = new OutlierDetection(fluent.getBaseEjectionTime(),fluent.getConsecutive5xxErrors(),fluent.getConsecutiveErrors(),fluent.getConsecutiveGatewayErrors(),fluent.getConsecutiveLocalOriginFailures(),fluent.getInterval(),fluent.getMaxEjectionPercent(),fluent.getMinHealthPercent(),fluent.getSplitExternalLocalOriginErrors());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OutlierDetectionBuilder that = (OutlierDetectionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> istio-model-v1beta1-6.5.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/OutlierDetectionBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class OutlierDetectionBuilder extends OutlierDetectionFluentImpl<OutlierDetectionBuilder> implements VisitableBuilder<OutlierDetection,OutlierDetectionBuilder>{
  public OutlierDetectionBuilder() {
    this(false);
  }
  public OutlierDetectionBuilder(Boolean validationEnabled) {
    this(new OutlierDetection(), validationEnabled);
  }
  public OutlierDetectionBuilder(OutlierDetectionFluent<?> fluent) {
    this(fluent, false);
  }
  public OutlierDetectionBuilder(OutlierDetectionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new OutlierDetection(), validationEnabled);
  }
  public OutlierDetectionBuilder(OutlierDetectionFluent<?> fluent,OutlierDetection instance) {
    this(fluent, instance, false);
  }
  public OutlierDetectionBuilder(OutlierDetectionFluent<?> fluent,OutlierDetection instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withBaseEjectionTime(instance.getBaseEjectionTime()); 
    fluent.withConsecutive5xxErrors(instance.getConsecutive5xxErrors()); 
    fluent.withConsecutiveErrors(instance.getConsecutiveErrors()); 
    fluent.withConsecutiveGatewayErrors(instance.getConsecutiveGatewayErrors()); 
    fluent.withConsecutiveLocalOriginFailures(instance.getConsecutiveLocalOriginFailures()); 
    fluent.withInterval(instance.getInterval()); 
    fluent.withMaxEjectionPercent(instance.getMaxEjectionPercent()); 
    fluent.withMinHealthPercent(instance.getMinHealthPercent()); 
    fluent.withSplitExternalLocalOriginErrors(instance.getSplitExternalLocalOriginErrors()); 
    this.validationEnabled = validationEnabled; 
  }
  public OutlierDetectionBuilder(OutlierDetection instance) {
    this(instance,false);
  }
  public OutlierDetectionBuilder(OutlierDetection instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withBaseEjectionTime(instance.getBaseEjectionTime()); 
    this.withConsecutive5xxErrors(instance.getConsecutive5xxErrors()); 
    this.withConsecutiveErrors(instance.getConsecutiveErrors()); 
    this.withConsecutiveGatewayErrors(instance.getConsecutiveGatewayErrors()); 
    this.withConsecutiveLocalOriginFailures(instance.getConsecutiveLocalOriginFailures()); 
    this.withInterval(instance.getInterval()); 
    this.withMaxEjectionPercent(instance.getMaxEjectionPercent()); 
    this.withMinHealthPercent(instance.getMinHealthPercent()); 
    this.withSplitExternalLocalOriginErrors(instance.getSplitExternalLocalOriginErrors()); 
    this.validationEnabled = validationEnabled; 
  }
  OutlierDetectionFluent<?> fluent;
  Boolean validationEnabled;
  public OutlierDetection build() {
    OutlierDetection buildable = new OutlierDetection(fluent.getBaseEjectionTime(),fluent.getConsecutive5xxErrors(),fluent.getConsecutiveErrors(),fluent.getConsecutiveGatewayErrors(),fluent.getConsecutiveLocalOriginFailures(),fluent.getInterval(),fluent.getMaxEjectionPercent(),fluent.getMinHealthPercent(),fluent.getSplitExternalLocalOriginErrors());
    return buildable;
  }
  
}
